import React, { useState } from "react";
import styled from "styled-components";
import Loading from "../../util/Loading";
import PlayerNameInput from "./PlayerNameInput";
import NewGameInput from "./NewGameInput"
import JoinGameInput from "./JoinGameInput";
import { createGame, joinGame } from "../../../domain/GGSHService";

const Container = styled.div`
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-around;
  align-items: center;

  @media only screen and (min-width: 600px) {
    flex-flow: row nowrap;
    justify-content: space-around;
  }
`

const Divider = styled.hr`
  margin-left: 75px;
  margin-right: 75px;
  align-self: stretch;

  @media only screen and (min-width: 600px) {
    margin-left: 0;
    margin-right: 0;
    align-self: stretch;
  }
`

export default ({ initPlayerName, onGameJoined }) => {
  const [loading, setLoading] = useState(false);
  const [gameId, setGameId] = useState(null);
  const [playerName, setPlayerName] = useState(initPlayerName);
  const [timer, setTimer] = useState(300);

  if (loading) {
    return <Loading/>
  }

  const onChangePlayerName = ({ target }) => setPlayerName(target.value);
  const onChangeGameId = ({ target }) => setGameId(target.value.trim());
  const onCreateGame = async () => {
    setLoading(true);
    const gameId = await createGame(playerName, timer);
    onGameJoined({ gameId, playerName });
  };
  const cannotCreateGame = !playerName || playerName.length === 0;
  const onJoinGame = async () => {
    // TODO would like to support re-joining a game you left
    setLoading(true);
    await joinGame(gameId, playerName);
    onGameJoined({ gameId, playerName });
  };
  const cannotJoinGame = cannotCreateGame || !gameId || gameId.length === 0;

  return (
    <Container>
      <PlayerNameInput {...{ playerName, onChangePlayerName }} />
      <Divider/>
      <NewGameInput {...{ onCreateGame, cannotCreateGame, timer, setTimer }} />
      <Divider/>
      <JoinGameInput {...{ gameId, onChangeGameId, onJoinGame, cannotJoinGame }} />
    </Container>
  );
}
